@@ -1,7 +1,7 @@
 from pydantic import (
     BaseModel, HttpUrl
 )
-from typing import Optional
+from typing import Optional, List
 
 
 class Meta(BaseModel):
@@ -20,3 +20,4 @@ class EvaluationMeta(BaseModel):
     request_id: Optional[str]
     prediction_model_name: Optional[str]
     label_model_name: Optional[str]
+    metrics: Optional[List]
